==> spark-kubernetes-operator-0.4.0.tar.gz: spark-kubernetes-operator-0.4.0/spark-submission-worker/src/main/java/org/apache/spark/k8s/operator/utils/ConfigMapSpecUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.spark.k8s.operator.utils;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import io.fabric8.kubernetes.api.model.ConfigMap;
import io.fabric8.kubernetes.api.model.ConfigMapBuilder;

import org.apache.spark.k8s.operator.spec.ConfigMapSpec;

/** Utility class for ConfigMap specifications. */
public final class ConfigMapSpecUtils {
  private ConfigMapSpecUtils() {}

  public static List<ConfigMap> buildConfigMaps(List<ConfigMapSpec> configMapMountList) {
    if (configMapMountList == null || configMapMountList.isEmpty()) {
      return Collections.emptyList();
    }
    return configMapMountList.stream()
        .map(
            c ->
                new ConfigMapBuilder()
                    .editOrNewMetadata()
                    .withName(c.getName())
                    .withLabels(c.getLabels())
                    .withAnnotations(c.getAnnotations())
                    .endMetadata()
                    .addToData(c.getData())
                    .build())
        .collect(Collectors.toList());
  }
}

==> spark-kubernetes-operator-0.5.0.tar.gz: spark-kubernetes-operator-0.5.0/spark-submission-worker/src/main/java/org/apache/spark/k8s/operator/utils/ConfigMapSpecUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.spark.k8s.operator.utils;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import io.fabric8.kubernetes.api.model.ConfigMap;
import io.fabric8.kubernetes.api.model.ConfigMapBuilder;

import org.apache.spark.k8s.operator.spec.ConfigMapSpec;

/** Utility class for ConfigMap specifications. */
public final class ConfigMapSpecUtils {
  private ConfigMapSpecUtils() {}

  /**
   * Builds a list of Kubernetes ConfigMap objects from a list of ConfigMapSpec.
   *
   * @param configMapMountList A list of ConfigMapSpec objects.
   * @return A List of ConfigMap objects.
   */
  public static List<ConfigMap> buildConfigMaps(List<ConfigMapSpec> configMapMountList) {
    if (configMapMountList == null || configMapMountList.isEmpty()) {
      return Collections.emptyList();
    }
    return configMapMountList.stream()
        .map(
            c ->
                new ConfigMapBuilder()
                    .editOrNewMetadata()
                    .withName(c.getName())
                    .withLabels(c.getLabels())
                    .withAnnotations(c.getAnnotations())
                    .endMetadata()
                    .addToData(c.getData())
                    .build())
        .collect(Collectors.toList());
  }
}
